@@ -13,33 +13,38 @@ from security.config import settings
 from security.utils import get_object_triple
 
 
+undefined = object()
+
+
 class SecurityLogger(ContextDecorator, local):
 
     loggers = []
-    name = None
+    logger_name = None
     store = True
 
-    def __init__(self, id=None, parent_key=None, related_objects=None, slug=None, data=None, extra_data=None):
-        self.id = id or (uuid4() if self.name else None)
+    def __init__(self, id=None, parent_log=undefined, related_objects=None, slug=None, extra_data=None,
+                 start=None, stop=None, error_message=None, time=None, release=None):
+        self.id = id or (uuid4() if self.logger_name else None)
         self.parent = SecurityLogger.loggers[-1] if SecurityLogger.loggers else None
 
         self.related_objects = set()
         if related_objects:
             self.add_related_objects(*related_objects)
 
+        self.start = start
+        self.stop = stop
+        self.error_message = error_message
+        self.release = release or settings.RELEASE
+
         self.slug = slug
         if self.parent:
             self.related_objects |= self.parent.related_objects
             if not self.slug:
                 self.slug = self.parent.slug
-        self.data = {}
-        if data:
-            self.data.update(data)
-
         parent_with_id = self._get_parent_with_id()
-        self.parent_key = (
-            '{}|{}'.format(parent_with_id.name, parent_with_id.id) if parent_with_id else None
-        ) if parent_key is None else parent_key
+        self.parent_log = (
+            '{}|{}'.format(parent_with_id.logger_name, parent_with_id.id) if parent_with_id else None
+        ) if parent_log is undefined else parent_log
 
         self._extra_data = extra_data
         if self._extra_data is None:
@@ -61,6 +66,10 @@ class SecurityLogger(ContextDecorator, local):
             parent = parent.parent
         return parent
 
+    @property
+    def time(self):
+        return (self.stop - self.start).total_seconds() if self.start and self.stop else None
+
     def __enter__(self):
         return self
 
@@ -91,10 +100,6 @@ class SecurityLogger(ContextDecorator, local):
 
             post_revision_commit.disconnect(self._post_revision_commit)
 
-    @property
-    def release(self):
-        return settings.RELEASE
-
     def _post_revision_commit(self, **kwargs):
         """
         Called as a post save of revision model of the reversion library.
@@ -111,9 +116,18 @@ class SecurityLogger(ContextDecorator, local):
             })
         reversion_data['total_count'] += 1
 
+    def to_dict(self):
+        return dict(
+            extra_data=self.extra_data,
+            time=self.time,
+            **{k: v for k, v in self.__dict__.items() if k not in {
+                'backend_logs', 'stream', 'store', 'logger_name', 'loggers', 'parent'
+            } and not k.startswith('_')}
+        )
+
 
 def get_last_logger(name):
     for logger in SecurityLogger.loggers[::-1]:
-        if logger.name == name:
+        if logger.logger_name == name:
             return logger
     return None
